//
//  Localization.h
//  DevonAppKit
//
//  Created by Christian Grunenberg on 02.03.07.
//

#import <Cocoa/Cocoa.h>

#define LOCALIZATION_H

// Localizes title, toolTip and submenus

@interface NSMenu (DevonLocalizationExtensions)

-(void)localize;
-(void)localizeUsingTable:(NSString *)table;
-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;

-(void)localizeKeyEquivalents;
-(void)localizeKeyEquivalentsUsingTable:(NSString *)table;
-(void)localizeKeyEquivalentsUsingTable:(NSString *)table bundle:(NSBundle *)bundle;

-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes title and toolTip

@interface NSMenuItem (DevonLocalizationExtensions)

-(void)localize;
-(void)localizeUsingTable:(NSString *)table;
-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;

-(void)localizeKeyEquivalent;
-(void)localizeKeyEquivalentUsingTable:(NSString *)table;
-(void)localizeKeyEquivalentUsingTable:(NSString *)table bundle:(NSBundle *)bundle;

-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes title and subviews

@interface NSWindow (DevonLocalizationExtensions)

-(void)localize;
-(void)localizeUsingTable:(NSString *)table;
-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;

-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes toolbar items

@interface NSToolbar (DevonLocalizationExtensions)

-(void)localize;
-(void)localizeUsingTable:(NSString *)table;
-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes label, paletteLabel and toolTip

@interface NSToolbarItem (DevonLocalizationExtensions)

-(void)localize;
-(void)localizeUsingTable:(NSString *)table;
-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes subviews

@interface NSDrawer (DevonLocalizationExtensions)

-(void)localize;
-(void)localizeUsingTable:(NSString *)table;
-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes toolTip, title, string and menu

@interface NSView (DevonLocalizationExtensions)

-(void)localize;
-(void)localizeUsingTable:(NSString *)table;
-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes title only if visible

@interface NSBox (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes alternateTitle too

@interface NSButton (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Doesn't localize title

@interface NSPopUpButton (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes stringValue and placeholderString too

@interface NSTextField (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes tableColumns and menus of data cells too

@interface NSTableView (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes title and placeholderString of cells too

@interface NSMatrix (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes label and view of tabViewItems too

@interface NSTabView (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Localizes label and toolTip of segments too

@interface NSSegmentedControl (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

// Doesn't localize

@interface NSRuleEditor (DevonLocalizationExtensions)

-(void)localizeUsingTable:(NSString *)table bundle:(NSBundle *)bundle;
-(void)replaceString:(NSString *)oldStr withString:(NSString *)newStr;

@end

@interface NSBundle (StringsFiles)

-(NSDictionary *)stringsFileNamed:(NSString *)file;
-(NSDictionary *)stringsFilesNamed:(NSString *)file1, ... NS_REQUIRES_NIL_TERMINATION;

@end

@interface NSDictionary (StringsFiles)

-(NSData *)stringsRepresentation;
-(BOOL)writeStringsToFile:(NSString *)path atomically:(BOOL)atomically;

@end
